// test-Volume.cpp
//
// Copyright © 1998 Arcane Dragon Software
//                  Chris Herborth (chrish@kagi.com)
//
// Simple test of a ChVolume object; we'll find and list all of the
// index info on the boot volume.

#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include <string.h>
#include <kernel/fs_info.h>
#include <support/TypeConstants.h>

#include "Ch/ChVolume.h"

static char *_rcs_id = "$Id: test-Volume.cpp,v 1.2 1998/04/14 00:34:05 chrish Exp $";

int main( void )
{
	printf( "ChVolume test\n" );
	printf( "%s\n", _rcs_id );
	printf( "\n" );

	ChVolume vol( dev_for_path( "/boot" ) );

	// We'll try to list the names and info for all the indexes on /boot.
	char name[B_FILE_NAME_LENGTH];
	while( vol.GetNextIndexName( name ) == B_NO_ERROR ) {
		printf( "Found an index named \"%s\":\n", name );

		struct index_info info;
		status_t retval = vol.GetIndexInfo( name, &info );
		if( retval == B_NO_ERROR ) {
			printf( "\ttype is " );
			switch( info.type ) {
			case B_INT32_TYPE:
				printf( "32-bit integer" );
				break;

			case B_INT64_TYPE:
				printf( "64-bit integer" );
				break;

			case B_STRING_TYPE:
				printf( "string" );
				break;

			case B_FLOAT_TYPE:
				printf( "single-precision floating-point" );
				break;

			case B_DOUBLE_TYPE:
				printf( "double-precision floating-point" );
				break;

			default:
				printf( "unknown type (0x08%x)", info.type );
				break;
			}
			printf( "\n" );

			printf( "\tsize is %Ld\n", info.size );
			printf( "\tlast modified on %s", ctime( &info.modification_time ) );
			printf( "\tcreated on %s", ctime( &info.creation_time ) );
		} else {
			printf( "\tCouldn't read the index info.\n" );
		}
	}
	
	return EXIT_SUCCESS;
}
